====================
Oslo Context Library
====================

.. image:: https://img.shields.io/pypi/v/oslo.context.svg
    :target: https://pypi.python.org/pypi/oslo.context/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.context.svg
    :target: https://pypi.python.org/pypi/oslo.context/
    :alt: Downloads

The Oslo context library has helpers to maintain useful information
about a request context. The request context is usually populated in
the WSGI pipeline and used by various modules such as logging.

* License: Apache License, Version 2.0
* Documentation: http://docs.openstack.org/developer/oslo.context
* Source: http://git.openstack.org/cgit/openstack/oslo.context
* Bugs: http://bugs.launchpad.net/oslo.context
